/****************************************************************************/
/*                                                                          */
/* ./grid/seg.c   -   Convert to Swedish Grid based on the datum RT90       */
/*                                                                          */
/* This file is part of gpstrans - a program to communicate with garmin gps */
/* Parts are taken from John F. Waers (jfwaers@csn.net) program MacGPS.     */
/*                                                                          */
/*                                                                          */
/*    Copyright (c) 1995 by Carsten Tschach (tschach@zedat.fu-berlin.de)    */
/* Copyright (c) 1999 by Anders Lennartsson (anders.lennartsson@sto.foa.se) */
/*                                                                          */
/* Permission  to use, copy,  modify, and distribute  this software and its */
/* documentation for non-commercial purpose, is hereby granted without fee, */
/* providing that the  copyright notice  appear in all copies and that both */
/* the  copyright notice and  this permission  notice appear in  supporting */
/* documentation.  I make no representations about  the suitability of this */
/* software  for any  purpose.  It is  provides "as is" without  express or */
/* implid warranty.                                                         */
/*                                                                          */
/****************************************************************************/
#include "defs.h"
#include "Garmin.h"
#include <math.h>

/* define constants */
static const double lat0   = 0.0; /* reference transverse mercator latitude */
                                  /* for SEG: the equator of Bessel's 1841 ellipsoid */
static const double lon0   = 15.808277777778; /* reference longitude */
                                  /* for SEG: 2.5 gon east of Stockholm's old observatory  */
static const double k0     = 1.0;

/****************************************************************************/
/* Convert degree to Swedish Grid Format.                                   */
/****************************************************************************/
void DegToSEG(double lat, double lon, double *x, double *y)
{
  toTM(lat, lon, lat0, lon0, k0, x, y);
 
  /* add false easting and round to nearest meter */ 
  *y = floor(*y + 0.5);
  *x = floor(*x + 1500000.5);
  /* realistic values */
  /* 6100000m < x < 7700000m */
  /* 1200000m < y < 1900000m */
}


/****************************************************************************/
/* Convert Swedish Grid Format to degree.                                   */
/****************************************************************************/
void SEGtoDeg(double x, double y, double *lat, double *lon)
{
  x -= 1500000.0;
  
  fromTM(x, y, lat0, lon0, k0, lat, lon);
}
